@@ -20,7 +20,7 @@
 #ifndef KREPORTEXAMPLE_WINDOW_H
 #define KREPORTEXAMPLE_WINDOW_H
 
-#include "KReportExampleData.h"
+#include "KReportExampleDataSource.h"
 
 #include <QMainWindow>
 #include <QDomDocument>
@@ -38,13 +38,13 @@ class Window : public QMainWindow
     Q_OBJECT
 public:
     Window(QWidget *parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags());
-    virtual ~Window();
+    ~Window() override;
 
 public Q_SLOTS:
     void showDesign(const QDomElement &design);
 
 protected:
-    void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
+    void closeEvent(QCloseEvent *event) override;
 
 private:
     void createMenus();
