@@ -26,17 +26,17 @@ KREPORT_DECLARE_STATIC_PLUGIN(KReportCheckBoxPlugin)
 
 class KReportCheckBoxPlugin : public KReportPluginInterface
 {
-    public:
-        explicit KReportCheckBoxPlugin(QObject *parent, const QVariantList &args = QVariantList());
-        ~KReportCheckBoxPlugin() override;
+public:
+    explicit KReportCheckBoxPlugin(QObject *parent, const QVariantList &args = QVariantList());
+    ~KReportCheckBoxPlugin() override;
 
-        QObject *createRendererInstance(const QDomNode &element) override;
-        QObject *createDesignerInstance(const QDomNode &element, KReportDesigner *,
-                                        QGraphicsScene *scene) override;
-        QObject *createDesignerInstance(KReportDesigner *, QGraphicsScene *scene,
-                                        const QPointF &pos) override;
+    QObject *createRendererInstance(const QDomNode &element) override;
+    QObject *createDesignerInstance(const QDomNode &element, KReportDesigner *designer,
+                                    QGraphicsScene *scene) override;
+    QObject *createDesignerInstance(KReportDesigner *designer, QGraphicsScene *scene,
+                                    const QPointF &pos) override;
 #ifdef KREPORT_SCRIPTING
-        QObject *createScriptInstance(KReportItemBase *item) override;
+    QObject *createScriptInstance(KReportItemBase *item) override;
 #endif
 };
 
