@@ -31,8 +31,10 @@ class KReportDesignerItemCheckBox : public KReportItemCheckBox, public KReportDe
 {
     Q_OBJECT
 public:
-    KReportDesignerItemCheckBox(KReportDesigner *, QGraphicsScene * scene, const QPointF &pos);
-    KReportDesignerItemCheckBox(const QDomNode & element, KReportDesigner *, QGraphicsScene * scene);
+    KReportDesignerItemCheckBox(KReportDesigner *designer, QGraphicsScene *scene,
+                                const QPointF &pos);
+    KReportDesignerItemCheckBox(const QDomNode &element, KReportDesigner *designer,
+                                QGraphicsScene *scene);
 
     ~KReportDesignerItemCheckBox() override;
 
@@ -43,13 +45,10 @@ public:
     KReportDesignerItemCheckBox* clone() override;
 
 private:
-    void init(QGraphicsScene*, KReportDesigner*);
+    void init(QGraphicsScene *scene);
 
 private Q_SLOTS:
     void slotPropertyChanged(KPropertySet &, KProperty &);
-
-protected:
-    void mousePressEvent(QGraphicsSceneMouseEvent * event) override;
 };
 
 #endif // KREPORTDESIGNERITEMCHECK_H
