@@ -31,9 +31,9 @@ public:
     ~KReportImagePlugin() override;
 
     QObject *createRendererInstance(const QDomNode &element) override;
-    QObject *createDesignerInstance(const QDomNode &element, KReportDesigner *,
+    QObject *createDesignerInstance(const QDomNode &element, KReportDesigner *designer,
                                     QGraphicsScene *scene) override;
-    QObject *createDesignerInstance(KReportDesigner *, QGraphicsScene *scene,
+    QObject *createDesignerInstance(KReportDesigner *designer, QGraphicsScene *scene,
                                     const QPointF &pos) override;
 #ifdef KREPORT_SCRIPTING
     QObject *createScriptInstance(KReportItemBase *item) override;
