@@ -17,9 +17,11 @@
 
 #include "KReportItemLabel.h"
 #include "KReportRenderObjects.h"
+#include "KReportUtils.h"
 #include "kreportplugin_debug.h"
 
 #include <KPropertySet>
+#include <KPropertyListData>
 
 #include <QFontDatabase>
 #include <QPalette>
@@ -31,26 +33,25 @@ KReportItemLabel::KReportItemLabel()
 }
 
 KReportItemLabel::KReportItemLabel(const QDomNode & element)
+    : KReportItemLabel()
 {
-    createProperties();
-    QDomNodeList nl = element.childNodes();
-    QString n;
-    QDomNode node;
-
-    m_name->setValue(element.toElement().attribute(QLatin1String("report:name")));
+    nameProperty()->setValue(KReportUtils::readNameAttribute(element.toElement()));
     m_text->setValue(element.toElement().attribute(QLatin1String("report:caption")));
-    Z = element.toElement().attribute(QLatin1String("report:z-index")).toDouble();
+    setZ(element.toElement().attribute(QLatin1String("report:z-index")).toDouble());
     m_horizontalAlignment->setValue(element.toElement().attribute(QLatin1String("report:horizontal-align")));
     m_verticalAlignment->setValue(element.toElement().attribute(QLatin1String("report:vertical-align")));
 
-    parseReportRect(element.toElement(), &m_pos, &m_size);
+    parseReportRect(element.toElement());
 
+    QDomNodeList nl = element.childNodes();
+    QString n;
+    QDomNode node;
     for (int i = 0; i < nl.count(); i++) {
         node = nl.item(i);
         n = node.nodeName();
 
         if (n == QLatin1String("report:text-style")) {
-            KRTextStyleData ts;
+            KReportTextStyleData ts;
             if (parseReportTextStyleData(node.toElement(), &ts)) {
                 m_backgroundColor->setValue(ts.backgroundColor);
                 m_foregroundColor->setValue(ts.foregroundColor);
@@ -61,19 +62,18 @@ KReportItemLabel::KReportItemLabel(const QDomNode & element)
         } else if (n == QLatin1String("report:line-style")) {
             KReportLineStyle ls;
             if (parseReportLineStyleData(node.toElement(), &ls)) {
-                m_lineWeight->setValue(ls.width());
+                m_lineWeight->setValue(ls.weight());
                 m_lineColor->setValue(ls.color());
-                m_lineStyle->setValue(QPen(ls.penStyle()));
+                m_lineStyle->setValue(static_cast<int>(ls.penStyle()));
             }
         } else {
-            kreportpluginWarning() << "while parsing label element encountered unknow element: " << n;
+            kreportpluginWarning() << "while parsing label element encountered unknown element: " << n;
         }
     }
 }
 
 KReportItemLabel::~KReportItemLabel()
 {
-    delete m_set;
 }
 
 QString KReportItemLabel::text() const
@@ -88,20 +88,18 @@ void KReportItemLabel::setText(const QString& t)
 
 void KReportItemLabel::createProperties()
 {
-    m_set = new KPropertySet;
-
     m_text = new KProperty("caption", QLatin1String("Label"), tr("Caption"));
-    QStringList keys, strings;
+    KPropertyListData *listData = new KPropertyListData(
+        { QLatin1String("left"), QLatin1String("center"), QLatin1String("right") },
+        QVariantList{ tr("Left"), tr("Center"), tr("Right") });
+    m_horizontalAlignment = new KProperty("horizontal-align", listData, QLatin1String("left"),
+                                          tr("Horizontal Alignment"));
 
-    keys << QLatin1String("left") << QLatin1String("center") << QLatin1String("right");
-    strings << tr("Left") << tr("Center") << tr("Right");
-    m_horizontalAlignment = new KProperty("horizontal-align", keys, strings, QLatin1String("left"), tr("Horizontal Alignment"));
-
-    keys.clear();
-    strings.clear();
-    keys << QLatin1String("top") << QLatin1String("center") << QLatin1String("bottom");
-    strings << tr("Top") << tr("Center") << tr("Bottom");
-    m_verticalAlignment = new KProperty("vertical-align", keys, strings, QLatin1String("center"), tr("Vertical Alignment"));
+    listData = new KPropertyListData(
+        { QLatin1String("top"), QLatin1String("center"), QLatin1String("bottom") },
+        QVariantList{ tr("Top"), tr("Center"), tr("Bottom") });
+    m_verticalAlignment = new KProperty("vertical-align", listData, QLatin1String("center"),
+                                        tr("Vertical Alignment"));
 
     m_font = new KProperty("font", QFontDatabase::systemFont(QFontDatabase::GeneralFont), tr("Font"), tr("Font"));
 
@@ -111,23 +109,23 @@ void KReportItemLabel::createProperties()
     m_backgroundOpacity = new KProperty("background-opacity", QVariant(0), tr("Background Opacity"));
     m_backgroundOpacity->setOption("max", 100);
     m_backgroundOpacity->setOption("min", 0);
-    m_backgroundOpacity->setOption("unit", QLatin1String("%"));
+    m_backgroundOpacity->setOption("suffix", QLatin1String("%"));
 
-    m_lineWeight = new KProperty("line-weight", 1, tr("Line Weight"));
+    m_lineWeight = new KProperty("line-weight", 1.0, tr("Line Weight"));
+    m_lineWeight->setOption("step", 1.0);
     m_lineColor = new KProperty("line-color", QColor(Qt::black), tr("Line Color"));
-    m_lineStyle = new KProperty("line-style", QPen(Qt::NoPen), tr("Line Style"), tr("Line Style"), KProperty::LineStyle);
+    m_lineStyle = new KProperty("line-style", static_cast<int>(Qt::NoPen), tr("Line Style"), QString(), KProperty::LineStyle);
 
-    addDefaultProperties();
-    m_set->addProperty(m_text);
-    m_set->addProperty(m_horizontalAlignment);
-    m_set->addProperty(m_verticalAlignment);
-    m_set->addProperty(m_font);
-    m_set->addProperty(m_backgroundColor);
-    m_set->addProperty(m_foregroundColor);
-    m_set->addProperty(m_backgroundOpacity);
-    m_set->addProperty(m_lineWeight);
-    m_set->addProperty(m_lineColor);
-    m_set->addProperty(m_lineStyle);
+    propertySet()->addProperty(m_text);
+    propertySet()->addProperty(m_horizontalAlignment);
+    propertySet()->addProperty(m_verticalAlignment);
+    propertySet()->addProperty(m_font);
+    propertySet()->addProperty(m_backgroundColor);
+    propertySet()->addProperty(m_foregroundColor);
+    propertySet()->addProperty(m_backgroundOpacity);
+    propertySet()->addProperty(m_lineWeight);
+    propertySet()->addProperty(m_lineColor);
+    propertySet()->addProperty(m_lineStyle);
 }
 
 Qt::Alignment KReportItemLabel::textFlags() const
@@ -153,9 +151,9 @@ Qt::Alignment KReportItemLabel::textFlags() const
     return align;
 }
 
-KRTextStyleData KReportItemLabel::textStyle() const
+KReportTextStyleData KReportItemLabel::textStyle() const
 {
-    KRTextStyleData d;
+    KReportTextStyleData d;
     d.backgroundColor = m_backgroundColor->value().value<QColor>();
     d.foregroundColor = m_foregroundColor->value().value<QColor>();
     d.font = m_font->value().value<QFont>();
@@ -166,7 +164,7 @@ KRTextStyleData KReportItemLabel::textStyle() const
 KReportLineStyle KReportItemLabel::lineStyle() const
 {
     KReportLineStyle ls;
-    ls.setWidth(m_lineWeight->value().toInt());
+    ls.setWeight(m_lineWeight->value().toReal());
     ls.setColor(m_lineColor->value().value<QColor>());
     ls.setPenStyle((Qt::PenStyle)m_lineStyle->value().toInt());
     return ls;
@@ -185,8 +183,8 @@ int KReportItemLabel::renderSimpleData(OROPage *page, OROSection *section, const
     Q_UNUSED(script)
 
     OROTextBox * tb = new OROTextBox();
-    tb->setPosition(m_pos.toScene() + offset);
-    tb->setSize(m_size.toScene());
+    tb->setPosition(scenePosition(position()) + offset);
+    tb->setSize(sceneSize(size()));
     tb->setFont(font());
     tb->setText(text());
     tb->setFlags(textFlags());
@@ -194,12 +192,12 @@ int KReportItemLabel::renderSimpleData(OROPage *page, OROSection *section, const
     tb->setLineStyle(lineStyle());
 
     if (page) {
-        page->addPrimitive(tb);
+        page->insertPrimitive(tb);
     }
 
     if (section) {
         OROPrimitive *clone = tb->clone();
-        clone->setPosition(m_pos.toScene());
+        clone->setPosition(scenePosition(position()));
         section->addPrimitive(clone);
     }
 
