@@ -18,7 +18,9 @@
 #include "KReportItemText.h"
 #include "KReportRenderObjects.h"
 #include "kreportplugin_debug.h"
+#include "KReportUtils.h"
 
+#include <KPropertyListData>
 #include <KPropertySet>
 
 #include <QPrinter>
@@ -26,6 +28,7 @@
 #include <QPalette>
 #include <QFontMetrics>
 #include <QDomNodeList>
+#include <QRegularExpression>
 
 KReportItemText::KReportItemText()
     : m_bottomPadding(0.0)
@@ -36,26 +39,25 @@ KReportItemText::KReportItemText()
 KReportItemText::KReportItemText(const QDomNode & element)
   : KReportItemText()
 {
-    QDomNodeList nl = element.childNodes();
-    QString n;
-    QDomNode node;
-
-    m_name->setValue(element.toElement().attribute(QLatin1String("report:name")));
-    m_controlSource->setValue(element.toElement().attribute(QLatin1String("report:item-data-source")));
+    nameProperty()->setValue(KReportUtils::readNameAttribute(element.toElement()));
+    setItemDataSource(element.toElement().attribute(QLatin1String("report:item-data-source")));
     m_itemValue->setValue(element.toElement().attribute(QLatin1String("report:value")));
-    Z = element.toElement().attribute(QLatin1String("report:z-index")).toDouble();
+    setZ(element.toElement().attribute(QLatin1String("report:z-index")).toDouble());
     m_horizontalAlignment->setValue(element.toElement().attribute(QLatin1String("report:horizontal-align")));
     m_verticalAlignment->setValue(element.toElement().attribute(QLatin1String("report:vertical-align")));
     m_bottomPadding = element.toElement().attribute(QLatin1String("report:bottom-padding")).toDouble();
 
-    parseReportRect(element.toElement(), &m_pos, &m_size);
+    parseReportRect(element.toElement());
 
+    QDomNodeList nl = element.childNodes();
+    QString n;
+    QDomNode node;
     for (int i = 0; i < nl.count(); i++) {
         node = nl.item(i);
         n = node.nodeName();
 
         if (n == QLatin1String("report:text-style")) {
-            KRTextStyleData ts;
+            KReportTextStyleData ts;
             if (parseReportTextStyleData(node.toElement(), &ts)) {
                 m_backgroundColor->setValue(ts.backgroundColor);
                 m_foregroundColor->setValue(ts.foregroundColor);
@@ -66,7 +68,7 @@ KReportItemText::KReportItemText(const QDomNode & element)
         } else if (n == QLatin1String("report:line-style")) {
             KReportLineStyle ls;
             if (parseReportLineStyleData(node.toElement(), &ls)) {
-                m_lineWeight->setValue(ls.width());
+                m_lineWeight->setValue(ls.weight());
                 m_lineColor->setValue(ls.color());
                 m_lineStyle->setValue(static_cast<int>(ls.penStyle()));
             }
@@ -79,7 +81,6 @@ KReportItemText::KReportItemText(const QDomNode & element)
 
 KReportItemText::~KReportItemText()
 {
-    delete m_set;
 }
 
 Qt::Alignment KReportItemText::textFlags() const
@@ -107,26 +108,21 @@ Qt::Alignment KReportItemText::textFlags() const
 
 void KReportItemText::createProperties()
 {
-    m_set = new KPropertySet;
-
-    //connect ( set, SIGNAL ( propertyChanged ( KPropertySet &, KProperty & ) ), this, SLOT ( propertyChanged ( KPropertySet &, KProperty & ) ) );
-
-    QStringList keys, strings;
-
-    //_query = new KProperty ( "Query", QStringList(), QStringList(), "Data Source", "Query" );
-    m_controlSource = new KProperty("item-data-source", QStringList(), QStringList(), QString(), tr("Data Source"));
+    createDataSourceProperty();
 
     m_itemValue = new KProperty("value", QString(), tr("Value"), tr("Value used if not bound to a field"));
 
-    keys << QLatin1String("left") << QLatin1String("center") << QLatin1String("right");
-    strings << tr("Left") << tr("Center") << tr("Right");
-    m_horizontalAlignment = new KProperty("horizontal-align", keys, strings, QLatin1String("left"), tr("Horizontal Alignment"));
+    KPropertyListData *listData = new KPropertyListData(
+        { QLatin1String("left"), QLatin1String("center"), QLatin1String("right") },
+        QVariantList{ tr("Left"), tr("Center"), tr("Right") });
+    m_horizontalAlignment = new KProperty("horizontal-align", listData, QLatin1String("left"),
+                                          tr("Horizontal Alignment"));
 
-    keys.clear();
-    strings.clear();
-    keys << QLatin1String("top") << QLatin1String("center") << QLatin1String("bottom");
-    strings << tr("Top") << tr("Center") << tr("Bottom");
-    m_verticalAlignment = new KProperty("vertical-align", keys, strings, QLatin1String("center"), tr("Vertical Alignment"));
+    listData = new KPropertyListData(
+        { QLatin1String("top"), QLatin1String("center"), QLatin1String("bottom") },
+        QVariantList{ tr("Top"), tr("Center"), tr("Bottom") });
+    m_verticalAlignment = new KProperty("vertical-align", listData, QLatin1String("center"),
+                                        tr("Vertical Alignment"));
 
     m_font = new KProperty("font", QApplication::font(), tr("Font"));
 
@@ -136,32 +132,25 @@ void KReportItemText::createProperties()
     m_lineWeight = new KProperty("line-weight", 1.0, tr("Line Weight"));
     m_lineWeight->setOption("step", 1.0);
     m_lineColor = new KProperty("line-color", QColor(Qt::black), tr("Line Color"));
-    m_lineStyle = new KProperty("line-style", static_cast<int>(Qt::NoPen), tr("Line Style"), tr("Line Style"), KProperty::LineStyle);
+    m_lineStyle = new KProperty("line-style", static_cast<int>(Qt::NoPen), tr("Line Style"), QString(), KProperty::LineStyle);
     m_backgroundOpacity = new KProperty("background-opacity", QVariant(0), tr("Background Opacity"));
     m_backgroundOpacity->setOption("max", 100);
     m_backgroundOpacity->setOption("min", 0);
-    m_backgroundOpacity->setOption("unit", QLatin1String("%"));
+    m_backgroundOpacity->setOption("suffix", QLatin1String("%"));
 
-    addDefaultProperties();
-    m_set->addProperty(m_controlSource);
-    m_set->addProperty(m_itemValue);
-    m_set->addProperty(m_horizontalAlignment);
-    m_set->addProperty(m_verticalAlignment);
-    m_set->addProperty(m_font);
-    m_set->addProperty(m_backgroundColor);
-    m_set->addProperty(m_foregroundColor);
-    m_set->addProperty(m_backgroundOpacity);
-    m_set->addProperty(m_lineWeight);
-    m_set->addProperty(m_lineColor);
-    m_set->addProperty(m_lineStyle);
+    propertySet()->addProperty(m_itemValue);
+    propertySet()->addProperty(m_horizontalAlignment);
+    propertySet()->addProperty(m_verticalAlignment);
+    propertySet()->addProperty(m_font);
+    propertySet()->addProperty(m_backgroundColor);
+    propertySet()->addProperty(m_foregroundColor);
+    propertySet()->addProperty(m_backgroundOpacity);
+    propertySet()->addProperty(m_lineWeight);
+    propertySet()->addProperty(m_lineColor);
+    propertySet()->addProperty(m_lineStyle);
 
 }
 
-QString KReportItemText::itemDataSource() const
-{
-    return m_controlSource->value().toString();
-}
-
 qreal KReportItemText::bottomPadding() const
 {
     return m_bottomPadding;
@@ -174,9 +163,9 @@ void KReportItemText::setBottomPadding(qreal bp)
     }
 }
 
-KRTextStyleData KReportItemText::textStyle() const
+KReportTextStyleData KReportItemText::textStyle() const
 {
-    KRTextStyleData d;
+    KReportTextStyleData d;
     d.backgroundColor = m_backgroundColor->value().value<QColor>();
     d.foregroundColor = m_foregroundColor->value().value<QColor>();
     d.font = m_font->value().value<QFont>();
@@ -187,7 +176,7 @@ KRTextStyleData KReportItemText::textStyle() const
 KReportLineStyle KReportItemText::lineStyle() const
 {
     KReportLineStyle ls;
-    ls.setWidth(m_lineWeight->value().toReal());
+    ls.setWeight(m_lineWeight->value().toReal());
     ls.setColor(m_lineColor->value().value<QColor>());
     ls.setPenStyle((Qt::PenStyle)m_lineStyle->value().toInt());
     return ls;
@@ -210,20 +199,16 @@ int KReportItemText::renderSimpleData(OROPage *page, OROSection *section, const
     QString cs = itemDataSource();
 
     if (!cs.isEmpty()) {
-        if (cs.left(1) == QLatin1String("$")) { //Everything past $ is treated as a string
-            qstrValue = cs.mid(1);
-        } else {
-            qstrValue = data.toString();
-        }
+        qstrValue = data.toString();
     } else {
         qstrValue = m_itemValue->value().toString();
     }
 
-    QPointF pos = m_pos.toScene();
-    QSizeF size = m_size.toScene();
+    QPointF pos = scenePosition(position());
+    QSizeF siz = sceneSize(size());
     pos += offset;
 
-    QRectF trf(pos, size);
+    QRectF trf(pos, siz);
     qreal intStretch = trf.top() - offset.y();
 
     if (qstrValue.length()) {
@@ -231,18 +216,19 @@ int KReportItemText::renderSimpleData(OROPage *page, OROSection *section, const
 
         int pos = 0;
         QChar separator;
-        QRegExp re(QLatin1String("\\s"));
+        QRegularExpression re(QLatin1String("\\s"));
         QPrinter prnt(QPrinter::HighResolution);
-        QFontMetrics fm(font(), &prnt);
+        QFontMetricsF fm(font(), &prnt);
 
         // int   intRectWidth    = (int)(trf.width() * prnt.resolution()) - 10;
-        int     intRectWidth    = (int)((m_size.toPoint().width() / 72) * prnt.resolution());
+        int     intRectWidth    = (int)((size().width() / 72) * prnt.resolution());
         int     intLineCounter  = 0;
         qreal   intBaseTop      = trf.top();
         qreal   intRectHeight   = trf.height();
 
         while (qstrValue.length()) {
-            int idx = re.indexIn(qstrValue, pos);
+            QRegularExpressionMatch match = re.match(qstrValue);
+            int idx = match.capturedStart(pos);
             if (idx == -1) {
                 idx = qstrValue.length();
                 separator = QLatin1Char('\n');
@@ -271,13 +257,15 @@ int KReportItemText::renderSimpleData(OROPage *page, OROSection *section, const
                     tb->setLineStyle(lineStyle());
 
                     if (page) {
-                        page->addPrimitive(tb);
+                        page->insertPrimitive(tb);
                     }
 
                     if (section) {
                         OROTextBox *tb2 = dynamic_cast<OROTextBox*>(tb->clone());
-                        tb2->setPosition(m_pos.toPoint());
-                        section->addPrimitive(tb2);
+                        if (tb2) {
+                            tb2->setPosition(scenePosition(position()));
+                            section->addPrimitive(tb2);
+                        }
                     }
 
                     if (!page) {
@@ -304,7 +292,7 @@ int KReportItemText::renderSimpleData(OROPage *page, OROSection *section, const
                 tb->setTextStyle(textStyle());
                 tb->setLineStyle(lineStyle());
                 if (page) {
-                    page->addPrimitive(tb);
+                    page->insertPrimitive(tb);
                 } else {
                     delete tb;
                 }
