@@ -97,7 +97,7 @@ int codeIndex(QChar code)
 }
 
 
-void render3of9(OROPage * page, const QRectF & r, const QString & _str, int align)
+void render3of9(OROPage * page, const QRectF & r, const QString & _str, Qt::Alignment align)
 {
     QString str = _str;
     // lets determine some core attributes about this barcode
@@ -141,12 +141,13 @@ void render3of9(OROPage * page, const QRectF & r, const QString & _str, int alig
     //
     // calculate the starting position based on the alignment option
     // for left align we don't need to do anything as the values are already setup for it
-    if (align == 1) { // center
+    if (align == Qt::AlignHCenter) {
         qreal nqz = (draw_width - L) / 2.0;
         if (nqz > quiet_zone)
             quiet_zone = nqz;
-    } else if (align > 1)  // right
+    } else if (align == Qt::AlignRight) {
         quiet_zone = draw_width - (L + quiet_zone);
+    }
     //else if(align < 1) {} // left : do nothing
 
     qreal pos = r.left() + quiet_zone;
@@ -177,7 +178,7 @@ void render3of9(OROPage * page, const QRectF & r, const QString & _str, int alig
                 rect->setPen(pen);
                 rect->setBrush(brush);
                 rect->setRect(QRectF(pos, top, w, draw_height));
-                page->addPrimitive(rect);
+                page->insertPrimitive(rect);
             }
             pos += w;
         }
