@@ -16,8 +16,10 @@
  */
 
 #include "KReportItemBarcode.h"
+#include "KReportUtils.h"
 
 #include <KProperty>
+#include <KPropertyListData>
 #include <KPropertySet>
 
 #include <QDomNode>
@@ -27,26 +29,22 @@
 #include "barcodes.h"
 
 KReportItemBarcode::KReportItemBarcode()
+    : m_minWidthData(0), m_minWidthTotal(0), m_minHeight(0)
 {
     createProperties();
 }
 
 KReportItemBarcode::KReportItemBarcode(const QDomNode & element)
+    : KReportItemBarcode()
 {
-    createProperties();
-    QDomNodeList nl = element.childNodes();
-    QString n;
-    QDomNode node;
-
-    m_name->setValue(element.toElement().attribute(QLatin1String("report:name")));
-    m_controlSource->setValue(element.toElement().attribute(QLatin1String("report:item-data-source")));
+    nameProperty()->setValue(KReportUtils::readNameAttribute(element.toElement()));
+    setItemDataSource(element.toElement().attribute(QLatin1String("report:item-data-source")));
     m_itemValue->setValue(element.toElement().attribute(QLatin1String("report:value")));
-    Z = element.toElement().attribute(QLatin1String("report:z-index")).toDouble();
+    setZ(element.toElement().attribute(QLatin1String("report:z-index")).toDouble());
     m_horizontalAlignment->setValue(element.toElement().attribute(QLatin1String("report:horizontal-align")));
-    m_maxLength->setValue(element.toElement().attribute(QLatin1String("report:barcode-max-length")));
+    m_maxLength->setValue(element.toElement().attribute(QLatin1String("report:barcode-max-length")).toInt());
     m_format->setValue(element.toElement().attribute(QLatin1String("report:barcode-format")));
-    parseReportRect(element.toElement(), &m_pos, &m_size);
-
+    parseReportRect(element.toElement());
 }
 
 void KReportItemBarcode::setMaxLength(int i)
@@ -61,8 +59,9 @@ void KReportItemBarcode::setMaxLength(int i)
             int X = 1; // narrow line width
             int I = 1; // interchange line width
             m_minWidthData = (((C + 2) * ((3 * N) + 6) * X) + ((C + 1) * I)) / 100.0;
-            m_minHeight = m_minWidthData * 0.15;
-            /*if(min_height < 0.25)*/ m_minHeight = 0.25;
+            //m_minHeight = m_minWidthData * 0.15;
+            /*if(min_height < 0.25)*/
+            m_minHeight = 0.25;
             m_minWidthTotal = m_minWidthData + 0.22; // added a little buffer to make sure we don't loose any
             // of our required quiet zone in conversions
         } else if (m_format->value().toString() == QLatin1String("3of9+")) {
@@ -71,8 +70,9 @@ void KReportItemBarcode::setMaxLength(int i)
             int X = 1; // 1px narrow line
             int I = 1; // 1px narrow line interchange
             m_minWidthData = (((C + 2) * ((3 * N) + 6) * X) + ((C + 1) * I)) / 100.0;
-            m_minHeight = m_minWidthData * 0.15;
-            /*if(min_height < 0.25)*/ m_minHeight = 0.25;
+            //m_minHeight = m_minWidthData * 0.15;
+            /*if(min_height < 0.25)*/
+            m_minHeight = 0.25;
             m_minWidthTotal = m_minWidthData + 0.22; // added a little buffer to make sure we don't loose any
             // of our required quiet zone in conversions
         } else if (m_format->value().toString() == QLatin1String("i2of5")) {
@@ -115,78 +115,60 @@ void KReportItemBarcode::setMaxLength(int i)
 
 void KReportItemBarcode::createProperties()
 {
-    m_set = new KPropertySet;
-
-    QStringList keys, strings;
-
-    m_controlSource = new KProperty("item-data-source", QStringList(), QStringList(),
-                                    QString(), tr("Data Source"));
+    createDataSourceProperty();
 
     m_itemValue = new KProperty("value", QString(), tr("Value"),
                                 tr("Value used if not bound to a field"));
 
-    keys << QLatin1String("left") << QLatin1String("center") << QLatin1String("right");
-    strings << tr("Left") << tr("Center") << tr("Right");
-    m_horizontalAlignment = new KProperty("horizontal-align", keys, strings,
-                                          QLatin1String("left"), tr("Horizontal Alignment"));
+    KPropertyListData *listData = new KPropertyListData(
+        { QLatin1String("left"), QLatin1String("center"), QLatin1String("right") },
+        QVariantList{ tr("Left"), tr("Center"), tr("Right") });
+    m_horizontalAlignment = new KProperty("horizontal-align", listData, QLatin1String("left"),
+                                          tr("Horizontal Alignment"));
 
-    keys.clear();
-    strings.clear();
-    keys << QLatin1String("3of9") << QLatin1String("3of9+") << QLatin1String("128")
+    listData = new KPropertyListData(
+    QStringList()
+         << QLatin1String("3of9") << QLatin1String("3of9+") << QLatin1String("128")
          << QLatin1String("ean8") << QLatin1String("ean13") << QLatin1String("i2of5")
-         << QLatin1String("upc-a") << QLatin1String("upc-e");
-    strings << tr("Code 3 of 9", "Barcode symbology, keep short")
+         << QLatin1String("upc-a") << QLatin1String("upc-e"),
+    QStringList()
+            << tr("Code 3 of 9", "Barcode symbology, keep short")
             << tr("Code 3 of 9 Ext.", "3 of 3 Extended: Barcode symbology, keep short")
             << tr("Code 128", "Barcode symbology, keep short")
             << tr("EAN-8", "Barcode symbology, keep short")
             << tr("EAN-13", "Barcode symbology, keep short")
             << tr("Interleaved 2 of 5", "Interleaved barcode 2 of 5: barcode symbology, keep short")
             << tr("UPC-A", "Barcode symbology, keep short")
-            << tr("UPC-E", "Barcode symbology, keep short");
-    m_format = new KProperty("barcode-format", keys, strings, QLatin1String("3of9"),
+            << tr("UPC-E", "Barcode symbology, keep short")
+    );
+    m_format = new KProperty("barcode-format", listData, QLatin1String("3of9"),
                              tr("Barcode Format"));
 
     m_maxLength = new KProperty("barcode-max-length", 5, tr("Max Length"),
                                 tr("Maximum Barcode Length"));
 
-    addDefaultProperties();
-    m_set->addProperty(m_controlSource);
-    m_set->addProperty(m_itemValue);
-    m_set->addProperty(m_format);
-    m_set->addProperty(m_horizontalAlignment);
-    m_set->addProperty(m_maxLength);
+    propertySet()->addProperty(m_itemValue);
+    propertySet()->addProperty(m_format);
+    propertySet()->addProperty(m_horizontalAlignment);
+    propertySet()->addProperty(m_maxLength);
 }
 
 KReportItemBarcode::~KReportItemBarcode()
 {
-    delete m_set;
 }
 
-int KReportItemBarcode::alignment()
+Qt::Alignment KReportItemBarcode::horizontalAlignment() const
 {
-    QByteArray a = m_horizontalAlignment->value().toByteArray();
-
-    if (a == "left")
-        return 0;
-    else if (a == "center")
-        return 1;
-    else if (a == "right")
-        return 2;
-    else
-        return 0;
+    return KReportUtils::horizontalAlignment(m_horizontalAlignment->value().toString(),
+                                             Qt::AlignLeft);
 }
 
-QString KReportItemBarcode::itemDataSource() const
-{
-    return m_controlSource->value().toString();
-}
-
-QString KReportItemBarcode::format()
+QString KReportItemBarcode::format() const
 {
     return m_format->value().toString();
 }
 
-int KReportItemBarcode::maxLength()
+int KReportItemBarcode::maxLength() const
 {
     return m_maxLength->value().toInt();
 }
@@ -196,9 +178,9 @@ void KReportItemBarcode::setFormat(const QString& f)
     m_format->setValue(f);
 }
 
-void KReportItemBarcode::setAlignment(int)
+void KReportItemBarcode::setHorizontalAlignment(Qt::Alignment value)
 {
-    //! @todo Barcode alignment
+    m_horizontalAlignment->setValue(KReportUtils::horizontalToString(value));
 }
 
 //RTTI
@@ -213,15 +195,15 @@ int KReportItemBarcode::renderSimpleData(OROPage *page, OROSection *section, con
     Q_UNUSED(section);
     Q_UNUSED(script);
 
-    QPointF pos = m_pos.toScene();
-    QSizeF size = m_size.toScene();
+    QPointF pos = scenePosition(position());
+    QSizeF siz = sceneSize(size());
     pos += offset;
 
-    QRectF rect = QRectF(pos, size);
+    QRectF rect = QRectF(pos, siz);
 
     QString val;
 
-    if (m_controlSource->value().toString().isEmpty()) {
+    if (itemDataSource().isEmpty()) {
         val = m_itemValue->value().toString();
     } else {
         val = data.toString();
@@ -229,7 +211,7 @@ int KReportItemBarcode::renderSimpleData(OROPage *page, OROSection *section, con
 
     if (page) {
         QByteArray fmt = m_format->value().toByteArray();
-        int align = alignment();
+        Qt::Alignment align = horizontalAlignment();
         if (fmt == "3of9")
             render3of9(page, rect, val, align);
         else if (fmt == "3of9+")
