@@ -79,7 +79,7 @@ static const int _upcparenc[10][2][6] = {
 };
 
 
-void renderCodeEAN13(const QRect & r, const QString & _str, int align, QPainter * pPainter)
+void renderCodeEAN13(const QRect & r, const QString & _str, Qt::Alignment align, QPainter * pPainter)
 {
     int val[13];
 
@@ -144,12 +144,13 @@ void renderCodeEAN13(const QRect & r, const QString & _str, int align, QPainter
     //
     // calculate the starting position based on the alignment option
     // for left align we don't need to do anything as the values are already setup for it
-    if (align == 1) {   // center
+    if (align == Qt::AlignHCenter) {
         int nqz = (draw_width - L) / 2;
         if (nqz > quiet_zone) quiet_zone = nqz;
-    } else if (align > 1) {  // right
+    } else if (align == Qt::AlignRight) {
         quiet_zone = draw_width - (L + quiet_zone);
-    } // else if(align < 1) {} // left : do nothing
+    }
+    // left : do nothing
 
     int pos = r.left() + quiet_zone;
     int top = r.top();
@@ -227,7 +228,7 @@ void renderCodeEAN13(const QRect & r, const QString & _str, int align, QPainter
     }
 }
 
-void renderCodeUPCA(const QRect & r, const QString & _str, int align, QPainter * pPainter)
+void renderCodeUPCA(const QRect & r, const QString & _str, Qt::Alignment align, QPainter * pPainter)
 {
     int val[13];
 
@@ -293,12 +294,13 @@ void renderCodeUPCA(const QRect & r, const QString & _str, int align, QPainter *
     //
     // calculate the starting position based on the alignment option
     // for left align we don't need to do anything as the values are already setup for it
-    if (align == 1) {   // center
+    if (align == Qt::AlignHCenter) {
         int nqz = (draw_width - L) / 2;
         if (nqz > quiet_zone) quiet_zone = nqz;
-    } else if (align > 1) {  // right
+    } else if (align == Qt::AlignRight) {
         quiet_zone = draw_width - (L + quiet_zone);
-    } // else if(align < 1) {} // left : do nothing
+    }
+    // left : do nothing
 
     int pos = r.left() + quiet_zone;
     int top = r.top();
@@ -380,7 +382,7 @@ void renderCodeUPCA(const QRect & r, const QString & _str, int align, QPainter *
     }
 }
 
-void renderCodeEAN8(const QRect & r, const QString & _str, int align, QPainter * pPainter)
+void renderCodeEAN8(const QRect & r, const QString & _str, Qt::Alignment align, QPainter * pPainter)
 {
     int val[8];
 
@@ -445,12 +447,13 @@ void renderCodeEAN8(const QRect & r, const QString & _str, int align, QPainter *
     //
     // calculate the starting position based on the alignment option
     // for left align we don't need to do anything as the values are already setup for it
-    if (align == 1) {   // center
+    if (align == Qt::AlignHCenter) {
         int nqz = (draw_width - L) / 2;
         if (nqz > quiet_zone) quiet_zone = nqz;
-    } else if (align > 1) {  // right
+    } else if (align == Qt::AlignRight) {
         quiet_zone = draw_width - (L + quiet_zone);
-    } // else if(align < 1) {} // left : do nothing
+    }
+    // left : do nothing
 
     int pos = r.left() + quiet_zone;
     int top = r.top();
@@ -524,7 +527,7 @@ void renderCodeEAN8(const QRect & r, const QString & _str, int align, QPainter *
     }
 }
 
-void renderCodeUPCE(const QRect & r, const QString & _str, int align, QPainter * pPainter)
+void renderCodeUPCE(const QRect & r, const QString & _str, Qt::Alignment align, QPainter * pPainter)
 {
     int val[8];
 
@@ -581,12 +584,13 @@ void renderCodeUPCE(const QRect & r, const QString & _str, int align, QPainter *
     //
     // calculate the starting position based on the alignment option
     // for left align we don't need to do anything as the values are already setup for it
-    if (align == 1) {   // center
+    if (align == Qt::AlignHCenter) {
         int nqz = (draw_width - L) / 2;
         if (nqz > quiet_zone) quiet_zone = nqz;
-    } else if (align > 1) {  // right
+    } else if (align == Qt::AlignRight) {
         quiet_zone = draw_width - (L + quiet_zone);
-    } // else if(align < 1) {} // left : do nothing
+    }
+    // left : do nothing
 
     int pos = r.left() + quiet_zone;
     int top = r.top();
