@@ -21,10 +21,8 @@
 #ifndef KREPORTITEMWEB_H
 #define KREPORTITEMWEB_H
 
-#include "KReportAsyncItemBase.h"
-#include "KReportPosition.h"
-#include "KReportSize.h"
-#include "KReportData.h"
+#include <KReportAsyncItemBase>
+#include <KReportDataSource>
 
 #include <QGraphicsScene>
 #include <QUrl>
@@ -46,27 +44,23 @@ class KReportItemWeb : public KReportAsyncItemBase
 public:
     KReportItemWeb();
     explicit KReportItemWeb(const QDomNode &element);
-    virtual ~KReportItemWeb();
+    ~KReportItemWeb() override;
 
-    virtual QString typeName() const;
-    virtual int renderSimpleData(OROPage *page, OROSection *section, const QPointF &offset, const QVariant &data, KReportScriptHandler *script);
-    virtual QString itemDataSource() const;
+    QString typeName() const override;
+    int renderSimpleData(OROPage *page, OROSection *section, const QPointF &offset, const QVariant &data, KReportScriptHandler *script) override;
 
 private Q_SLOTS:
     void loadFinished(bool);
 
 private:
-    void init();
-
     bool m_rendering;
     OROPage *m_targetPage;
     OROSection *m_targetSection;
     QPointF m_targetOffset;
 
 protected:
-    virtual void createProperties();
+    void createProperties() override;
 
-    KProperty *m_controlSource;
     QWebPage *m_webPage;
 
     friend class Scripting::Web;
