@@ -28,15 +28,6 @@ KReportWebPlugin::KReportWebPlugin(QObject *parent, const QVariantList &args)
     : KReportPluginInterface(parent)
 {
     Q_UNUSED(args)
-#if 0
-    KReportPluginMetaData *info = new KReportPluginInfo();
-    info->setClassName("web");
-    info->setName(tr("Web browser"));
-    info->setIcon(koIcon("report_web_element"));
-    info->setPriority(40);
-    
-    setInfo(info);
-#endif
 }
 
 KReportWebPlugin::~KReportWebPlugin()
@@ -67,7 +58,7 @@ QObject *KReportWebPlugin::createScriptInstance(KReportItemBase *item)
 //   KoReportItemweb *image = dynamic_cast<KoReportItemweb*>(item);
     // if (image) {
     //   return new Scripting::Web(image);
-    return 0;
+    return nullptr;
 }
 #endif
 
