@@ -30,7 +30,8 @@ class PrintRenderer : public KReportRendererBase
     public:
         PrintRenderer();
         ~PrintRenderer() override;
-        bool render(const KReportRendererContext&, ORODocument*, int page = -1) override;
+        bool render(const KReportRendererContext &context, ORODocument *document,
+                    int page = -1) override;
 
     private:
         bool setupPrinter(ORODocument *, QPrinter *);
