@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2015 by Adam Pigg (adam@piggz.co.uk)
+   Copyright (C) 2017 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,6 +30,7 @@
 #include <QScrollArea>
 #include <QLayout>
 #include <QPainter>
+#include <QPointer>
 #include <QPrintDialog>
 #include <QPrinter>
 #include <QGraphicsView>
@@ -36,12 +38,11 @@
 #include <QScrollBar>
 
 //! @internal
-class KReportView::Private
+class Q_DECL_HIDDEN KReportView::Private
 {
 public:
     explicit Private()
-        : reportDocument(0)
-        , reportPage(0)
+        : reportPage(nullptr)
         , currentPage(1)
         , pageCount(0)
     {}
@@ -49,7 +50,16 @@ public:
     ~Private()
     {}
 
-    ORODocument *reportDocument;
+    //! Move to page @a page (counted from 1)
+    void moveToPage(int page)
+    {
+        if (page != currentPage && page >= 1 && page <= pageCount) {
+            currentPage = page;
+            reportPage->renderPage(currentPage);
+        }
+    }
+
+    QPointer<ORODocument> reportDocument;
     QGraphicsView *reportView;
     QGraphicsScene *reportScene;
     KReportPage *reportPage;
@@ -91,34 +101,27 @@ KReportView::~KReportView()
 
 void KReportView::moveToFirstPage()
 {
-        if (d->currentPage != 1) {
-                d->currentPage = 1;
-                d->reportPage->renderPage(d->currentPage);
-        }
+    d->moveToPage(1);
 }
 
 void KReportView::moveToLastPage()
 {
-        if (d->currentPage != d->pageCount) {
-                d->currentPage = d->pageCount;
-                d->reportPage->renderPage(d->currentPage);
-        }
+    d->moveToPage(d->pageCount);
 }
 
 void KReportView::moveToNextPage()
 {
-        if (d->currentPage < d->pageCount) {
-                d->currentPage++;
-                d->reportPage->renderPage(d->currentPage);
-        }
+    d->moveToPage(d->currentPage + 1);
 }
 
 void KReportView::moveToPreviousPage()
 {
-        if (d->currentPage > 1) {
-                d->currentPage--;
-                d->reportPage->renderPage(d->currentPage);
-        }
+    d->moveToPage(d->currentPage - 1);
+}
+
+void KReportView::moveToPage(int page)
+{
+    d->moveToPage(page);
 }
 
 int KReportView::currentPage() const
@@ -139,7 +142,7 @@ void KReportView::setDocument(ORODocument* doc)
         delete d->reportPage;
     }
 
-    d->pageCount = doc->pages();
+    d->pageCount = doc->pageCount();
 
     d->reportPage = new KReportPage(this, d->reportDocument);
     d->reportPage->setObjectName(QLatin1String("KReportPage"));
@@ -158,7 +161,7 @@ QAbstractScrollArea* KReportView::scrollArea()
 
 void KReportView::refreshCurrentPage()
 {
-    //qDebug() << "Refreshing current page" << d->currentPage;
+    //kreportDebug() << "Refreshing current page" << d->currentPage;
     if (d->reportPage) {
         d->reportPage->renderPage(d->currentPage);
     }
