@@ -17,6 +17,7 @@
  */
 
 #include "KReportDesignerItemBase.h"
+#include "KReportDesigner.h"
 #include "KReportItemBase.h"
 #include "KReportUtils.h"
 
@@ -24,16 +25,35 @@
 #include <QDomDocument>
 #include <QCheckBox>
 
-//
-// ReportEntity
-//
-KReportDesignerItemBase::~KReportDesignerItemBase()
+class Q_DECL_HIDDEN KReportDesignerItemBase::Private
+{
+public:
+    Private();
+    ~Private();
+    
+    KReportDesigner *reportDesigner;
+    KReportItemBase *item;
+    QString renderText;   
+};
+
+KReportDesignerItemBase::Private::Private()
 {
 }
 
-KReportDesignerItemBase::KReportDesignerItemBase(KReportDesigner* r)
+KReportDesignerItemBase::Private::~Private()
 {
-    m_reportDesigner = r;
+}
+
+KReportDesignerItemBase::~KReportDesignerItemBase()
+{
+    delete d;
+}
+
+KReportDesignerItemBase::KReportDesignerItemBase(KReportDesigner *r, KReportItemBase *b) : d(new Private())
+{
+    d->reportDesigner = r;
+    d->item = b;
+    b->setUnit(r->pageUnit());
 }
 
 void KReportDesignerItemBase::buildXML(QGraphicsItem * item, QDomDocument *doc, QDomElement *parent)
@@ -47,13 +67,13 @@ void KReportDesignerItemBase::buildXML(QGraphicsItem * item, QDomDocument *doc,
 
 }
 
-void KReportDesignerItemBase::buildXMLRect(QDomDocument *doc, QDomElement *entity, KReportPosition *pos, KReportSize *size)
+void KReportDesignerItemBase::buildXMLRect(QDomDocument *doc, QDomElement *entity, KReportItemBase *i)
 {
     Q_UNUSED(doc);
-    KReportUtils::buildXMLRect(entity, pos, size);
+    KReportUtils::buildXMLRect(entity, i->position(), i->size());
 }
 
-void KReportDesignerItemBase::buildXMLTextStyle(QDomDocument *doc, QDomElement *entity, const KRTextStyleData &ts)
+void KReportDesignerItemBase::buildXMLTextStyle(QDomDocument *doc, QDomElement *entity, const KReportTextStyleData &ts)
 {
     KReportUtils::buildXMLTextStyle(doc, entity, ts);
 }
@@ -73,3 +93,28 @@ void KReportDesignerItemBase::addPropertyAsAttribute(QDomElement* e, KProperty*
 {
     KReportUtils::addPropertyAsAttribute(e, p);
 }
+
+KReportDesigner * KReportDesignerItemBase::designer() const
+{
+    return d->reportDesigner;
+}
+
+void KReportDesignerItemBase::setDesigner(KReportDesigner* rd)
+{
+    d->reportDesigner = rd;
+}
+
+KReportItemBase *KReportDesignerItemBase::item() const
+{
+    return d->item;
+}
+
+QString KReportDesignerItemBase::renderText() const
+{
+    return d->renderText;
+}
+
+void KReportDesignerItemBase::setRenderText(const QString& text)
+{
+    d->renderText = text;
+}
