@@ -27,7 +27,8 @@ class KReportDesignerSectionView : public QGraphicsView
 {
     Q_OBJECT
 public:
-    KReportDesignerSectionView(KReportDesigner *, QGraphicsScene * scene, QWidget * parent = nullptr);
+    KReportDesignerSectionView(KReportDesigner *designer, QGraphicsScene *scene,
+                               QWidget *parent = nullptr);
     ~KReportDesignerSectionView() override;
 
     KReportDesigner * designer() const;
